multipolynomial_bases: Sage implementation for bases of multipolynomials
========================================================================

Description
-----------

Sage implementation for bases of multipolynomials

License
-------

GPLv2

Upstream Contact
----------------

- https://pypi.org/project/multipolynomial-bases/
- https://github.com/passagemath/passagemath-pkg-multipolynomial-bases
